SketchyRandomPool class

A globally shared pool of random offsets for drawing organic sketchy animations.

Instead of every individual sketchy sentence instantiating 1000 random variables upon rendering, they all pull from this static pool. This significantly saves memory resources when many sketchy texts are drawn on screen.

Constructors

SketchyRandomPool()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

offsets List<double>
final